summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-31 00:38:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-31 00:38:51 -0600
commit44ff5a3c798fe9c44df30cc898fbdffa44784d56 (patch)
tree7e804b8a5d5d8f4e653766a8a867972e5e39eb38
parent5b6f5139f2f455cee37445c26a7036c76d7376bc (diff)
downloadtdesdk-44ff5a3c798fe9c44df30cc898fbdffa44784d56.tar.gz
tdesdk-44ff5a3c798fe9c44df30cc898fbdffa44784d56.zip
Rename KShared
-rw-r--r--kbabel/catalogmanager/catalogmanagerview.cpp4
-rw-r--r--kbabel/catalogmanager/libcvs/cvsdialog.cpp6
-rw-r--r--kbabel/catalogmanager/libcvs/cvsdialog.h4
-rw-r--r--kbabel/catalogmanager/libcvs/cvshandler.cpp6
-rw-r--r--kbabel/catalogmanager/libcvs/cvshandler.h8
-rw-r--r--kbabel/catalogmanager/libsvn/svndialog.cpp6
-rw-r--r--kbabel/catalogmanager/libsvn/svndialog.h6
-rw-r--r--kbabel/catalogmanager/libsvn/svnhandler.cpp6
-rw-r--r--kbabel/catalogmanager/libsvn/svnhandler.h8
-rw-r--r--kbabel/common/kbproject.cpp4
-rw-r--r--kbabel/common/kbproject.h10
-rw-r--r--kbabel/common/kbprojectmanager.cpp2
-rw-r--r--kbabel/kbabel/kbabel.cpp4
-rw-r--r--kbabel/kbabel/kbabel.h2
-rw-r--r--kbabel/kbabel/kbabelview.cpp2
-rw-r--r--kbabel/kbabel/kbabelview.h2
-rw-r--r--kbabel/kbabel/kbcatalogview.cpp2
-rw-r--r--kbabel/kbabel/kbcatalogview.h2
-rw-r--r--kbugbuster/backend/bug.h2
-rw-r--r--kbugbuster/backend/bugdetails.h2
-rw-r--r--kbugbuster/backend/bugdetailsimpl.h2
-rw-r--r--kbugbuster/backend/bugimpl.h2
-rw-r--r--kbugbuster/backend/package.h2
-rw-r--r--kbugbuster/backend/packageimpl.h2
24 files changed, 48 insertions, 48 deletions
diff --git a/kbabel/catalogmanager/catalogmanagerview.cpp b/kbabel/catalogmanager/catalogmanagerview.cpp
index de3ebf60..eab6c00e 100644
--- a/kbabel/catalogmanager/catalogmanagerview.cpp
+++ b/kbabel/catalogmanager/catalogmanagerview.cpp
@@ -1119,7 +1119,7 @@ void CatalogManagerView::cvsDiff( )
void CatalogManagerView::doCVSCommand( CVS::Command cmd, bool marked, bool templates )
{
- KSharedConfig* config = _project->sharedConfig();
+ TDESharedConfig* config = _project->sharedConfig();
if ( marked ) {
if ( _markerList.isEmpty() ) return;
TQStringList fileList;
@@ -1231,7 +1231,7 @@ void CatalogManagerView::svnDiff( )
void CatalogManagerView::doSVNCommand( SVN::Command cmd, bool marked, bool templates )
{
- KSharedConfig* config = _project->sharedConfig();
+ TDESharedConfig* config = _project->sharedConfig();
if ( marked ) {
if ( _markerList.isEmpty() ) return;
TQStringList fileList;
diff --git a/kbabel/catalogmanager/libcvs/cvsdialog.cpp b/kbabel/catalogmanager/libcvs/cvsdialog.cpp
index 27eee88f..ce4c4985 100644
--- a/kbabel/catalogmanager/libcvs/cvsdialog.cpp
+++ b/kbabel/catalogmanager/libcvs/cvsdialog.cpp
@@ -60,7 +60,7 @@
#include "cvsdialog.h"
-CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config )
+CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, TDESharedConfig* config )
: KDialog( parent, "CVSDIALOG", true ), m_config( config )
{
_cmd = cmd;
@@ -373,7 +373,7 @@ TQString CVSDialog::statusOutput( )
void CVSDialog::readSettings( )
{
- KSharedConfig * config = m_config;
+ TDESharedConfig * config = m_config;
config->setGroup( "CVSSupport" );
if ( _cmd == CVS::Commit ) {
@@ -404,7 +404,7 @@ void CVSDialog::readSettings( )
void CVSDialog::saveSettings( )
{
- KSharedConfig * config = m_config;
+ TDESharedConfig * config = m_config;
config->setGroup( "CVSSupport" );
if ( _cmd == CVS::Commit ) {
config->writeEntry( "AutoAddFiles", autoAddBox->isChecked( ) );
diff --git a/kbabel/catalogmanager/libcvs/cvsdialog.h b/kbabel/catalogmanager/libcvs/cvsdialog.h
index b62cccc9..3731148b 100644
--- a/kbabel/catalogmanager/libcvs/cvsdialog.h
+++ b/kbabel/catalogmanager/libcvs/cvsdialog.h
@@ -73,7 +73,7 @@ class CVSDialog : public KDialog
* Constructor for creating the dialog.
* @param cmd The type of command to be executed.
*/
- CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config );
+ CVSDialog( CVS::Command cmd, TQWidget * parent, TDESharedConfig* config );
~CVSDialog();
/**
* Set the list of files which will be used for the CVS command.
@@ -153,7 +153,7 @@ class CVSDialog : public KDialog
KComboBox* m_encodingComboBox;
/// Configuration data (of the KBabel project)
- KSharedConfig* m_config;
+ TDESharedConfig* m_config;
};
#endif // CVSDIALOG_H
diff --git a/kbabel/catalogmanager/libcvs/cvshandler.cpp b/kbabel/catalogmanager/libcvs/cvshandler.cpp
index d2b6c4eb..3b1c4b01 100644
--- a/kbabel/catalogmanager/libcvs/cvshandler.cpp
+++ b/kbabel/catalogmanager/libcvs/cvshandler.cpp
@@ -182,7 +182,7 @@ TQString CVSHandler::cvsStatus( const TQString& filename ) const
return map[filename];
}
-void CVSHandler::execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQString& filename, bool templates, KSharedConfig* config )
+void CVSHandler::execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQString& filename, bool templates, TDESharedConfig* config )
{
if ( !_isPORepository ) {
// This message box should never be visible but who knows... ;-)
@@ -221,7 +221,7 @@ void CVSHandler::execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQStr
showDialog( parent, cmd, TQStringList( filename ), command, config );
}
-void CVSHandler::execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config )
+void CVSHandler::execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQStringList& files, bool templates, TDESharedConfig* config )
{
if ( !_isPORepository ) {
// This message box should never be visible but who knows... ;-)
@@ -270,7 +270,7 @@ void CVSHandler::setAutoUpdateTemplates( bool update )
_autoUpdateTemplates = update;
}
-void CVSHandler::showDialog( TQWidget* parent, CVS::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config )
+void CVSHandler::showDialog( TQWidget* parent, CVS::Command cmd, const TQStringList& files, const TQString& commandLine, TDESharedConfig* config )
{
CVSDialog * dia = new CVSDialog( cmd, parent, config );
dia->setFiles( files );
diff --git a/kbabel/catalogmanager/libcvs/cvshandler.h b/kbabel/catalogmanager/libcvs/cvshandler.h
index 8d3fb85f..f5a0b7a4 100644
--- a/kbabel/catalogmanager/libcvs/cvshandler.h
+++ b/kbabel/catalogmanager/libcvs/cvshandler.h
@@ -46,7 +46,7 @@ class TQString;
class TQStringList;
class TQWidget;
-class KSharedConfig;
+class TDESharedConfig;
/**
* This class is the backend for CVS support in Catalog Manager.
@@ -79,8 +79,8 @@ class CVSHandler : public TQObject
TQString fileStatus( const FileStatus status ) const;
TQString cvsStatus( const TQString& filename ) const;
- void execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQString& filename, bool templates, KSharedConfig* config );
- void execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config );
+ void execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQString& filename, bool templates, TDESharedConfig* config );
+ void execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQStringList& files, bool templates, TDESharedConfig* config );
void setAutoUpdateTemplates( bool update );
@@ -95,7 +95,7 @@ class CVSHandler : public TQObject
void signalFilesCommitted( const TQStringList& );
private:
- void showDialog( TQWidget* parent, CVS::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config );
+ void showDialog( TQWidget* parent, CVS::Command cmd, const TQStringList& files, const TQString& commandLine, TDESharedConfig* config );
void checkToAdd( const TQStringList& files );
void processStatusOutput( const TQString& status );
void processDiff( TQString output );
diff --git a/kbabel/catalogmanager/libsvn/svndialog.cpp b/kbabel/catalogmanager/libsvn/svndialog.cpp
index 083ce22d..cd859d21 100644
--- a/kbabel/catalogmanager/libsvn/svndialog.cpp
+++ b/kbabel/catalogmanager/libsvn/svndialog.cpp
@@ -57,7 +57,7 @@
#include "svndialog.h"
-SVNDialog::SVNDialog( SVN::Command cmd, TQWidget * parent, KSharedConfig* config )
+SVNDialog::SVNDialog( SVN::Command cmd, TQWidget * parent, TDESharedConfig* config )
: KDialog( parent, "SVN DIALOG", true ), m_tempFile( 0 ), m_config( config )
{
_cmd = cmd;
@@ -352,7 +352,7 @@ TQString SVNDialog::statusOutput( )
void SVNDialog::readSettings( )
{
- KSharedConfig * config = m_config;
+ TDESharedConfig * config = m_config;
config->setGroup( "SVNSupport" );
if ( _cmd == SVN::Commit ) {
@@ -381,7 +381,7 @@ void SVNDialog::readSettings( )
void SVNDialog::saveSettings( )
{
- KSharedConfig * config = m_config;
+ TDESharedConfig * config = m_config;
config->setGroup( "SVNSupport" );
if ( _cmd == SVN::Commit ) {
config->writeEntry( "AutoAddFiles", autoAddBox->isChecked( ) );
diff --git a/kbabel/catalogmanager/libsvn/svndialog.h b/kbabel/catalogmanager/libsvn/svndialog.h
index 4190a172..6024d01c 100644
--- a/kbabel/catalogmanager/libsvn/svndialog.h
+++ b/kbabel/catalogmanager/libsvn/svndialog.h
@@ -50,7 +50,7 @@ class TQTextEdit;
// Forwarding KDE classes
class TDEProcess;
class KTempFile;
-class KSharedConfig;
+class TDESharedConfig;
/**
* This class represents the dialog which is used for executing SVN commands
@@ -72,7 +72,7 @@ class SVNDialog : public KDialog
* Constructor for creating the dialog.
* @param cmd The type of command to be executed.
*/
- SVNDialog( SVN::Command cmd, TQWidget * parent, KSharedConfig* config );
+ SVNDialog( SVN::Command cmd, TQWidget * parent, TDESharedConfig* config );
~SVNDialog();
/**
* Set the list of files which will be used for the SVN command.
@@ -146,7 +146,7 @@ class SVNDialog : public KDialog
KTempFile* m_tempFile;
/// Configuration data (of the KBabel project)
- KSharedConfig* m_config;
+ TDESharedConfig* m_config;
};
#endif // SVNDIALOG_H
diff --git a/kbabel/catalogmanager/libsvn/svnhandler.cpp b/kbabel/catalogmanager/libsvn/svnhandler.cpp
index a643f18a..18c08580 100644
--- a/kbabel/catalogmanager/libsvn/svnhandler.cpp
+++ b/kbabel/catalogmanager/libsvn/svnhandler.cpp
@@ -274,14 +274,14 @@ TQString SVNHandler::svnStatus( const TQString& filename ) const
return map[filename];
}
-void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config)
+void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, TDESharedConfig* config)
{
// Unlike cvs, svn works also from outside the repository(as long as the path is in a repository of course!)
// ### FIXME: wrong, svn commit cannot work if the current directory is not a SVN one
execSVNCommand( parent, cmd, TQStringList( filename ), templates, config );
}
-void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config )
+void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, TDESharedConfig* config )
{
if ( !_isPORepository ) {
// This message box should never be visible but who knows... ;-)
@@ -336,7 +336,7 @@ void SVNHandler::setAutoUpdateTemplates( bool update )
_autoUpdateTemplates = update;
}
-void SVNHandler::showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config )
+void SVNHandler::showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, TDESharedConfig* config )
{
SVNDialog * dia = new SVNDialog( cmd, parent, config );
dia->setFiles( files );
diff --git a/kbabel/catalogmanager/libsvn/svnhandler.h b/kbabel/catalogmanager/libsvn/svnhandler.h
index 4f2cda5c..57cc79ae 100644
--- a/kbabel/catalogmanager/libsvn/svnhandler.h
+++ b/kbabel/catalogmanager/libsvn/svnhandler.h
@@ -45,7 +45,7 @@
class TQString;
class TQStringList;
-class KSharedConfig;
+class TDESharedConfig;
/**
* This class is the backend for SVN support in Catalog Manager.
@@ -78,8 +78,8 @@ class SVNHandler : public TQObject
TQString fileStatus( const FileStatus status ) const;
TQString svnStatus( const TQString& filename ) const;
- void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config );
- void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config );
+ void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, TDESharedConfig* config );
+ void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, TDESharedConfig* config );
void setAutoUpdateTemplates( bool update );
@@ -94,7 +94,7 @@ class SVNHandler : public TQObject
void signalFilesCommitted( const TQStringList& );
private:
- void showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config );
+ void showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, TDESharedConfig* config );
/// Check quickly if the file is part of a SVN repository
bool isInSvn( const TQString& path );
void checkToAdd( const TQStringList& files );
diff --git a/kbabel/common/kbproject.cpp b/kbabel/common/kbproject.cpp
index f876627f..9700c08f 100644
--- a/kbabel/common/kbproject.cpp
+++ b/kbabel/common/kbproject.cpp
@@ -91,7 +91,7 @@ Project::Project( const TQString& file ) :
}
}
- _config = KSharedConfig::openConfig (_filename, false, false);
+ _config = TDESharedConfig::openConfig (_filename, false, false);
kdDebug (KBABEL) << "Opened project " << _filename << endl;
// read the project name
@@ -196,7 +196,7 @@ TDEConfig* Project::config ()
return _config;
}
-KSharedConfig* Project::sharedConfig( void )
+TDESharedConfig* Project::sharedConfig( void )
{
return _config;
}
diff --git a/kbabel/common/kbprojectmanager.cpp b/kbabel/common/kbprojectmanager.cpp
index 77a2fb9d..7b369ad7 100644
--- a/kbabel/common/kbprojectmanager.cpp
+++ b/kbabel/common/kbprojectmanager.cpp
@@ -93,7 +93,7 @@ Project::Ptr ProjectManager::create()
void ProjectManager::remove( Project* ref )
{
- kdDebug() << k_funcinfo << " Final remove of project " << (void*) ref << " count remaining: " << ref->_KShared_count() << endl;
+ kdDebug() << k_funcinfo << " Final remove of project " << (void*) ref << " count remaining: " << ref->_TDEShared_count() << endl;
p_list.remove (ref);
}
diff --git a/kbabel/kbabel/kbabel.cpp b/kbabel/kbabel/kbabel.cpp
index 79b21501..262e47ab 100644
--- a/kbabel/kbabel/kbabel.cpp
+++ b/kbabel/kbabel/kbabel.cpp
@@ -157,7 +157,7 @@ KBabelMW::KBabelMW(KBCatalog* catalog, TQString projectFile)
void KBabelMW::init(KBCatalog* catalog)
{
- _config = KSharedConfig::openConfig( "kbabelrc" );
+ _config = TDESharedConfig::openConfig( "kbabelrc" );
_toolsShortcuts.clear();
@@ -305,7 +305,7 @@ void KBabelMW::init(KBCatalog* catalog)
connect(m_view, TQT_SIGNAL(signalNewFileOpened(KURL)),
bmHandler, TQT_SLOT(slotClearBookmarks()));
- _config = KSharedConfig::openConfig( "kbabelrc" );
+ _config = TDESharedConfig::openConfig( "kbabelrc" );
restoreSettings();
_config->setGroup("KBabel");
diff --git a/kbabel/kbabel/kbabel.h b/kbabel/kbabel/kbabel.h
index 3f8dd42b..7e6b4913 100644
--- a/kbabel/kbabel/kbabel.h
+++ b/kbabel/kbabel/kbabel.h
@@ -314,7 +314,7 @@ private:
// project file
KBabel::Project::Ptr _project;
- KSharedConfig::Ptr _config;
+ TDESharedConfig::Ptr _config;
KBabel::ProjectDialog* _projectDialog;
TQMap<TQString,TQString> _toolsShortcuts;
diff --git a/kbabel/kbabel/kbabelview.cpp b/kbabel/kbabel/kbabelview.cpp
index 8380ad85..4a73b8bc 100644
--- a/kbabel/kbabel/kbabelview.cpp
+++ b/kbabel/kbabel/kbabelview.cpp
@@ -133,7 +133,7 @@ KBabelView::KBabelView(KBCatalog* catalog,KBabelMW *parent, Project::Ptr project
_catalog=catalog;
_catalog->registerView(this);
- _config = KSharedConfig::openConfig ("kbabelrc");
+ _config = TDESharedConfig::openConfig ("kbabelrc");
TDEConfigGroupSaver gs(_config,"Editor");
bool buildLeds=! KBabelSettings::ledInStatusbar();
diff --git a/kbabel/kbabel/kbabelview.h b/kbabel/kbabel/kbabelview.h
index 205f34a8..28766458 100644
--- a/kbabel/kbabel/kbabelview.h
+++ b/kbabel/kbabel/kbabelview.h
@@ -686,7 +686,7 @@ private:
private:
// configuration file
- KSharedConfig::Ptr _config;
+ TDESharedConfig::Ptr _config;
// project file
KBabel::Project::Ptr _project;
diff --git a/kbabel/kbabel/kbcatalogview.cpp b/kbabel/kbabel/kbcatalogview.cpp
index 40aee1c0..1871b221 100644
--- a/kbabel/kbabel/kbcatalogview.cpp
+++ b/kbabel/kbabel/kbcatalogview.cpp
@@ -45,7 +45,7 @@ KBCatalogView::KBCatalogView(KBCatalog* catalog, TQWidget* parent, Project::Ptr
_catalog=catalog;
_catalog->registerView(this);
- _config = KSharedConfig::openConfig ("kbabelrc");
+ _config = TDESharedConfig::openConfig ("kbabelrc");
_currentIndex=1; // here we use 1 to accept update at opening a file
diff --git a/kbabel/kbabel/kbcatalogview.h b/kbabel/kbabel/kbcatalogview.h
index 0c5ce17b..32bdbac4 100644
--- a/kbabel/kbabel/kbcatalogview.h
+++ b/kbabel/kbabel/kbcatalogview.h
@@ -95,7 +95,7 @@ protected:
uint _currentIndex;
// configuration file
- KSharedConfig::Ptr _config;
+ TDESharedConfig::Ptr _config;
// project file
KBabel::Project::Ptr _project;
};
diff --git a/kbugbuster/backend/bug.h b/kbugbuster/backend/bug.h
index 406179c8..a4de9e48 100644
--- a/kbugbuster/backend/bug.h
+++ b/kbugbuster/backend/bug.h
@@ -83,7 +83,7 @@ public:
private:
BugImpl *impl() const { return m_impl; }
- KSharedPtr<BugImpl> m_impl;
+ TDESharedPtr<BugImpl> m_impl;
};
#endif
diff --git a/kbugbuster/backend/bugdetails.h b/kbugbuster/backend/bugdetails.h
index 171847a7..45a426d4 100644
--- a/kbugbuster/backend/bugdetails.h
+++ b/kbugbuster/backend/bugdetails.h
@@ -46,7 +46,7 @@ public:
private:
BugDetailsImpl *impl() const { return m_impl; }
- KSharedPtr<BugDetailsImpl> m_impl;
+ TDESharedPtr<BugDetailsImpl> m_impl;
};
#endif
diff --git a/kbugbuster/backend/bugdetailsimpl.h b/kbugbuster/backend/bugdetailsimpl.h
index 5d6dc459..e4db5cd0 100644
--- a/kbugbuster/backend/bugdetailsimpl.h
+++ b/kbugbuster/backend/bugdetailsimpl.h
@@ -5,7 +5,7 @@
#include "bugdetailspart.h"
-struct BugDetailsImpl : public KShared
+struct BugDetailsImpl : public TDEShared
{
public:
BugDetailsImpl( const TQString &_version, const TQString &_source,
diff --git a/kbugbuster/backend/bugimpl.h b/kbugbuster/backend/bugimpl.h
index 7fefc53d..bddd6a4d 100644
--- a/kbugbuster/backend/bugimpl.h
+++ b/kbugbuster/backend/bugimpl.h
@@ -7,7 +7,7 @@
#include <kurl.h>
#include <ksharedptr.h>
-struct BugImpl : public KShared
+struct BugImpl : public TDEShared
{
public:
BugImpl( const TQString &_title, const Person &_submitter, TQString _number,
diff --git a/kbugbuster/backend/package.h b/kbugbuster/backend/package.h
index df0a119d..eecd067f 100644
--- a/kbugbuster/backend/package.h
+++ b/kbugbuster/backend/package.h
@@ -34,7 +34,7 @@ public:
bool operator<( const Package &rhs ) const;
private:
- KSharedPtr<PackageImpl> m_impl;
+ TDESharedPtr<PackageImpl> m_impl;
};
#endif
diff --git a/kbugbuster/backend/packageimpl.h b/kbugbuster/backend/packageimpl.h
index 30fd00af..0d7173c2 100644
--- a/kbugbuster/backend/packageimpl.h
+++ b/kbugbuster/backend/packageimpl.h
@@ -7,7 +7,7 @@
#include <kurl.h>
#include <ksharedptr.h>
-struct PackageImpl : public KShared
+struct PackageImpl : public TDEShared
{
public:
PackageImpl( const TQString &_name, const TQString &_description,
diff --git a/kbabel/common/kbproject.h b/kbabel/common/kbproject.h
index cedc97c8..85473328 100644
--- a/kbabel/common/kbproject.h
+++ b/kbabel/common/kbproject.h
@@ -43,12 +43,12 @@ namespace KBabel
{
class ProjectSettingsBase;
- class KDE_EXPORT Project : public TQObject, public KShared
+ class KDE_EXPORT Project : public TQObject, public TDEShared
{
Q_OBJECT
public:
- typedef KSharedPtr <Project> Ptr;
+ typedef TDESharedPtr <Project> Ptr;
Project( const TQString& file );
virtual ~Project ();
@@ -60,10 +60,10 @@ namespace KBabel
TDEConfig* config ();
/**
* Returns the KSharedConfig pointer of the project data
* @since 1.11.2 (KDE 3.5.2)
*/
- KSharedConfig* sharedConfig( void );
+ TDESharedConfig* sharedConfig( void );
ProjectSettingsBase* settings ();
@@ -101,7 +101,7 @@ namespace KBabel
TQString _filename;
TQString _name;
bool _valid;
- KSharedConfig::Ptr _config;
+ TDESharedConfig::Ptr _config;
ProjectSettingsBase* _settings;
};
@@ -60,10 +60,10 @@ namespace KBabel
TDEConfig* config ();
/**
- * Returns the KSharedConfig pointer of the project data
+ * Returns the TDESharedConfig pointer of the project data
* @since 1.11.2 (KDE 3.5.2)
*/